MtprotoClient class

add state data

Constructors

MtprotoClient({required int client_id, required Isolate isolate, int client_tg_user_id = 0})
TelegramClient

Properties

client_id ↔ int
TelegramClient
getter/setter pair
client_tg_user_id ↔ int
TelegramClient
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isolate ↔ Isolate
TelegramClient
getter/setter pair
join_date ↔ DateTime
TelegramClient
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
close
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
TelegramClientUncompleDocumentation
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited