MtprotoIsolateData class

TelegramClientUncompleDocumentation

Constructors

MtprotoIsolateData({required SendPort sendPort, required Map clientOption, required int clientId, required String pathMtproto, required bool isAndroid, required Duration delayUpdate, required double timeOutUpdate})
TelegramClientUncompleDocumentation

Properties

clientId ↔ int
TelegramClientUncompleDocumentation
getter/setter pair
clientOption ↔ Map
TelegramClientUncompleDocumentation
getter/setter pair
delayUpdate ↔ Duration
TelegramClientUncompleDocumentation
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAndroid ↔ bool
TelegramClientUncompleDocumentation
getter/setter pair
pathMtproto ↔ String
TelegramClientUncompleDocumentation
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendPort ↔ SendPort
TelegramClientUncompleDocumentation
getter/setter pair
timeOutUpdate ↔ double
TelegramClientUncompleDocumentation
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited