TdlibInvokeResult class

Constructors

TdlibInvokeResult({required int client_id, required Map result})
TelegramClientUncompleDocumentation
const

Properties

client_id → int
TelegramClientUncompleDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
result → Map
TelegramClientUncompleDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited