TdlibIsolateData class

TelegramClientUncompleDocumentation

Constructors

TdlibIsolateData({required SendPort sendPort, required String pathTdlib, required Duration? delayUpdate, required double timeOutUpdate})
TelegramClientUncompleDocumentation
const

Properties

delayUpdate → Duration?
TelegramClientUncompleDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
pathTdlib → String
TelegramClientUncompleDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendPort → SendPort
TelegramClientUncompleDocumentation
final
timeOutUpdate → double
TelegramClientUncompleDocumentation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited