UpdateTelegramClientTdlib class

Update td for make update support raw, raw api, raw api light

Constructors

UpdateTelegramClientTdlib({required Map update, required int client_id, required Map client_option})
TelegramClientUncompleDocumentation
const

Properties

client_id → int
TelegramClientUncompleDocumentation
final
client_option → Map
TelegramClientUncompleDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
raw → Map
return json update origin from api origin
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
return type update
no setter
update → Map
TelegramClientUncompleDocumentation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited