UpdateTelegramClientTelegramBotApi class

TelegramClientUncompleDocumentation

Constructors

UpdateTelegramClientTelegramBotApi({required Uri uri, required Map<String, dynamic> body, required Map query, required String type})
TelegramClientUncompleDocumentation
const

Properties

body → Map<String, dynamic>
TelegramClientUncompleDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
query → Map
TelegramClientUncompleDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
TelegramClientUncompleDocumentation
final
uri → Uri
TelegramClientUncompleDocumentation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited