UpdataMessageTelegramClient class

TelegramClientUncompleDocumentation

Constructors

UpdataMessageTelegramClient({bool bot_is_skip_old_message = false, bool user_is_skip_old_message = true, Duration? durationOldMessageSkip, List<String>? skipOldChatTypes})
TelegramClientUncompleDocumentation

Properties

bot_is_skip_old_message → bool
TelegramClientUncompleDocumentation
final
duration_old_message_skip ↔ Duration
TelegramClientUncompleDocumentation
latefinal
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skip_old_chat_types ↔ List<String>
TelegramClientUncompleDocumentation
latefinal
user_is_skip_old_message → bool
TelegramClientUncompleDocumentation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited