HttpSession class

run executable telegram bot api

Constructors

HttpSession({Client? httpClient})
run executable telegram bot api

Properties

cookies ↔ String
TelegramClientUncompleDocumentation
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
http_client ↔ Client
TelegramClientUncompleDocumentation
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCookiesFromCookiesInfo(String cookies, List<String> cookiesInfo) → String
run executable telegram bot api
get({required String url, required Map<String, String> headers, required Client? httpClient}) → Future<String>
run executable telegram bot api
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post({required String url, required Map<String, String> headers, required String body, required Client? httpClient}) → Future<String>
run executable telegram bot api
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited